/**
 * PushPullAsyncIterableIterator
 *
 * The iterable will publish values until return ot throw is called.
 * Afterwards it is in the completed state and cannot be used for publishing any further values.
 * It will handle back-pressure and keep pushed values until they are consumed by a source.
 */
export declare class PushPullAsyncIterableIterator<T> implements AsyncIterableIterator<T> {
    private pushQueue;
    private pullQueue;
    private isRunning;
    private errorValue;
    /**
     * Consume the next available value published on the iterable.
     * It will resolve with a value immediately (if any is present in the queue).
     * Otherwise, if no value is present, the subscriber will receive the next value once it is available.
     */
    next(): Promise<IteratorResult<T>>;
    /**
     * Complete a iterable. All pending consumer will receive a complete IteratorResult.
     * The iterable cannot be used to publish any more values after completing it.
     */
    return(): Promise<IteratorResult<T>>;
    /**
     * Throw a value and complete the iterable. After calling throw the next consumer will receive the error.
     * All further consumers will receive a complete IteratorResult.
     */
    throw(value: unknown): Promise<IteratorResult<T>>;
    [Symbol.asyncIterator](): this;
    private _handleError;
    /**
     * Push new values into the iterator. If any consumers are present it will be forwarded to the consumers.
     * Otherwise, the value will be saved until it is consumed.
     */
    push(value: T): void;
}
